@@ -1,12 +1,10 @@
 """Presets for the battery model."""
 
-import sys
 
-
-def battery_presets(pn_max_kw, **kwargs):
+def battery_preset(pn_max_kw, **kwargs):
 
     params = _get_dict(pn_max_kw, cap_kwh=kwargs.get("cap_kwh", pn_max_kw * 5))
-    inits = {"soc_percent": 50}
+    inits = {"soc_percent": kwargs.get("soc_percent", 50.0)}
 
     return params, inits
 
