@@ -368,6 +368,25 @@ class PysimmodsModule(UpgradeModule):
 
                     model_ctrs[model] += 1
 
+    def connect_to_timesim(self):
+        mapping_key = "peak_mapping"
+        timesim, _ = self.scenario.find_first_model("timesim")
+        model_ctrs = {}
+
+        for model, info in self.models.items():
+            for bus, entities in self.sim_params[mapping_key].items():
+                for name, _ in entities:
+                    if model != name:
+                        continue
+
+                    model_ctrs.setdefault(model, 0)
+                    model_key = self.scenario.generate_model_key(
+                        self, model.lower(), bus, model_ctrs[model]
+                    )
+                    self.connect_entities(timesim, model_key, ["local_time"])
+
+                    model_ctrs[model] += 1
+
     def generate_model_params(self, model_key, model, p_peak_mw):
         """Load model params and initial configurations."""
         mod_params, mod_inits = get_presets(
